@@ -1,6 +1,6 @@
 class RequestHeader:
 
-    def __init__(self, x_timestamp: str, x_signature: str, x_partner_id: str, x_external_id: str, channel_id: str, authorization: str):
+    def __init__(self, x_timestamp: str, x_signature: str, x_partner_id: str, x_external_id: str, authorization: str, channel_id: str="SDK"):
         self.x_timestamp = x_timestamp
         self.x_signature = x_signature
         self.x_partner_id = x_partner_id
