@@ -13,7 +13,8 @@ class PaymentNotificationRequest:
 
     def __init__(self, partnerServiceId: str, customerNo: str, virtualAccountNo: str,
                  virtualAccountName: str, trxId: str, paymentRequestId: str,
-                 paidAmount: TotalAmount, virtualAccountEmail: str, virtualAccountPhone: str, additionalInfo: PaymentNotificationAdditionalInfo) -> None:
+                 paidAmount: TotalAmount, virtualAccountEmail: str, virtualAccountPhone: str, additionalInfo: PaymentNotificationAdditionalInfo, virtualAccountTrxType: str,
+                 expiredDate: str) -> None:
         self.partner_service_id = partnerServiceId
         self.customer_no = customerNo
         self.virtual_acc_no = virtualAccountNo
@@ -24,3 +25,5 @@ class PaymentNotificationRequest:
         self.virtual_acc_email = virtualAccountEmail
         self.virtual_acc_phone = virtualAccountPhone
         self.additional_info = additionalInfo
+        self.virtual_acc_trx_type = virtualAccountTrxType
+        self.expired_date = expiredDate
