@@ -19,5 +19,5 @@ class NotificationVirtualAccountData:
             "virtualAccountNo": self.virtual_acc_no,
             "virtualAccountName": self.virtual_acc_name,
             "paymentRequestId": self.payment_request_id,
-            "additionalInfo": self.additional_info.json()
+            "additionalInfo": None if self.additional_info is None else self.additional_info.json()
         }
\ No newline at end of file
